
local    fedora = require "fedora.common"
local forgeauto = require "fedora.forgeauto"
local  buildsys = require "fedora.srpm.buildsys"

local namespace = "doc"

local rads = {
  ["key"]      = {"docs"},
  ["read"]     = {"epoch", "version", "license", "licenses",
                  "licenses_exclude", "docs", "docs_exclude", "tags"},
  ["computed"] = {"name", "summary", "requires", "description", "list"}
}

local function suffixes()
  return fedora.all_suffixes(fedora.qualify(rads["key"], namespace))
end

local function floop(f, index, otherargs, verbose)
  local range = suffixes(verbose)
  forgeauto.floop(f, index, range, otherargs)
end

local function radicals()
  local R = {}
  for k, v in pairs(rads) do
    R[k] = v
  end
  local all = {}
  for k, v in pairs(R) do
    all = fedora.mergelists({all, v})
  end
  R["all"] = all
  return R
end

local function init(suffix, verbose, informative)
 forgeauto.id(namespace .. '.init("' .. suffix .. '")')
  local ismain = (suffix == "") or (suffix == "0")
  local myrads = radicals()
  local requires = [[%{lua:
    local fedora = require "fedora.common"
    local namespace = "]] .. namespace .. [["
    local suffix    = "]] .. suffix .. [["
    local requires = {}
    local pkgs = fedora.read(namespace .. "_packages" .. suffix)
    if pkgs then
      for pkg in pkgs:gmatch("[^%s,;]+") do
        table.insert(requires, "Enhances:       " .. pkg)
      end
    else
      for _, z in ipairs(fedora.suffixes("buildsys_name")) do
        if not fedora.read("buildsys_name" .. z):match("-doc$") then
          table.insert(requires,
            "Enhances:       %{buildsys_name" .. z .. "}")
        end
      end
    end
    print(table.concat(requires, "\\n"))
    }]]
  fedora.mset(myrads["all"], namespace, suffix, {{
      ["name"]        = "%{source_name}-doc",
      ["summary"]     = "Optional documentation files %{source_name}",
      ["requires"]    = requires,
      ["description"] = [[
%{?source_description}

This package provides optional documentation files shipped with %{source_name}.
]],
      ["list"] = "%{_builddir}/%{?buildsubdir}/" ..
                 "%{" .. namespace .. "_name" .. suffix .. "}.lst",
    }}, verbose, false)
  if informative then
    fedora.echo("Variables read or set by %%" .. namespace .. "_init")
    fedora.echovars(fedora.qualify(myrads["all"], namespace), suffix)
  end
end

local function env(suffix, verbose)
  local myrads = radicals(suffix, verbose)
  fedora.set_current(fedora.qualify(myrads["all"], namespace), suffix, verbose)
end

local function pkg(suffix, verbose)
  forgeauto.id(namespace .. '.pkg("' .. suffix .. '")')
  fedora.mset(buildsys.radicals, "__current_buildsys", "", {
      { ["tags"] = [[
BuildArch:      noarch
%{?]] .. namespace .. [[_requires]] .. suffix .. [[}
%{?]] .. namespace .. [[_tags]]     .. suffix .. [[}]] },
      fedora.mread({"name", "summary", "epoch", "version", "license",
                    "description"}, namespace, suffix, false),
    }, verbose, true)
  buildsys.pkg(verbose)
end

return {
  suffixes = suffixes,
  floop    = floop,
  init     = init,
  env      = env,
  pkg      = pkg,
}
